# Imprint
(German version below)

Information in accordance with § 5 TMG

Brockmann Consult GmbH  
Chrysanderstraße 1  
21029 Hamburg  
Germany  

Phone: +49 40 696 389 300  
Fax: +49 40 696 389 399

E-Mail: info@brockmann-consult.de  
Internet: www.brockmann-consult.de

Representative: Dr. Carsten Brockmann, Managing Director

Commercial Register / Reg. No.: Amtsgericht Hamburg HRB 157689

VAT Identification No.: DE 223260395

Editorial responsibility: Dr Carsten Brockmann

Consumer dispute resolution/universal arbitration board:
We are not willing or obliged to participate in dispute resolution proceedings before a consumer arbitration board.

The web pages contain image material from Brockmann Consult GmbH, which was created using satellite data from ESA, 
Eumetsat, NASA, NOAA and USGS.

 

### Disclaimer

#### 1. Content of the online offer

The contents of our pages were created with great care. However, we cannot take any liability of accuracy, 
completeness and timeliness of the content. As a service provider, we are responsible for our own contents according to 
§ 7 Abs.1 TMG on these pages according to general laws. According to §§ 8 to 10 TMG we are as service providers 
not obliged to monitor transmitted or stored third-party information or investigate circumstances that might 
indicate illegal activity. Obligations to remove or block the use of information according to general laws 
remains unaffected. However, a liability in this regard is only possible from the point in time at which knowledge 
of a specific violation of the law is present. Upon notification of corresponding violations of the law, we will 
remove this content immediately.

#### 2. References and links

The authors are not responsible for any contents linked or referred to from their pages – unless they have full 
knowledge of illegal contents and would be able to prevent the visitors of their site fromviewing those pages. The 
authors hereby expressly declare that at the time the links were created, no illegal content was identifiable on 
the linked pages. The authors have no influence on the current and future design, content or authorship of the 
linked pages. For this reason, we hereby expressly distance ourselves from all contents of all linked pages that 
were changed after the link was created. This statement applies to all links and references set within the own 
Internet offer as well as to external entries in guest books, discussion forums and mailing lists set up by the 
authors. Liability for illegal, incorrect or incomplete content and in particular for damage arising from the use 
or non-use of such information lies solely with the provider of the site to which reference is made, and not with 
the party who merely refers to the publication in question via links.

#### 3. Legal validity of this disclaimer

This disclaimer is to be regarded as part of the internet publication which you were referred from. If sections or 
individual terms of this statement are not legal or correct, the content or validity of the other parts remain 
uninfluenced by this fact.

### Copyright

The content and works on these pages created by the site operators are subject to German copyright law.
The duplication, processing, distribution and any kind of exploitation outside the limits of copyright
require the written consent of the respective author or creator. Downloads and copies of this page are
permitted for private, non-commercial use only. If the content on this page is not provided by the website operator, 
the copyrights of third parties are followed. In particular, third-party content is marked as such. Should you 
nevertheless become aware of a copyright infringement, we ask for a notification about it.
As soon as we become aware of legal violations, we will remove such content immediately.

### Data protection

The use of our website is generally possible without providing personal data. If personal data are collecte via our 
pages (e.g. name, address or e-mail addresses), this happens if possible, always on a voluntary basis. These data 
will not be passed on to third parties without your express consent.
We would like to point out that data transmission via the Internet (e. g. when communicating by e-mail) security 
vulnerabilities may be present. A complete protection of the data against access by third parties is not possible.
The use of contact data published in the context of the imprint obligation by third parties for the transmission of  
non-expressly requested advertising and information materials are hereby objected to. Operators
of the pages reserve the right to take legal action in the event of unsolicited sending of advertising 
information, e. g. by spam mails.


# Impressum
Angaben gemäß § 5 TMG

Brockmann Consult GmbH  
Chrysanderstraße 1  
21029 Hamburg  
Germany  

Telefon: +49 40 696 389 300  
Fax: +49 40 696 389 399  

E-Mail: info@brockmann-consult.de  
Internet: www.brockmann-consult.de  

Vertreten durch: Dr. Carsten Brockmann, Managing Director

Registergericht / Handelsregister-Nr.: Amtsgericht Hamburg / HRB 157689

Umsatzsteuer-ID

Umsatzsteuer-Identifikationsnummer gemäß § 27 a Umsatzsteuergesetz:: DE 223260395

Redaktionell verantwortlich: Dr. Carsten Brockmann

Verbraucherstreitbeilegung/Universalschlichtungsstelle:  
Wir sind nicht bereit oder verpflichtet, an Streitbeilegungsverfahren vor einer
Verbraucherschlichtungsstelle teilzunehmen.

Die Webseiten enthalten Bildmaterial von Brockmann Consult GmbH, das unter Verwendung von Satellitendaten von ESA, 
Eumetsat, NASA, NOAA und USGS erstellt wurde.

 

### Haftungsausschluss

#### 1. Inhalt des Onlineangebotes

Die Inhalte unserer Seiten wurden mit größter Sorgfalt erstellt. Für die Richtigkeit, Vollständigkeit und Aktualität 
der Inhalte können wir jedoch keine Gewähr übernehmen. Als Diensteanbieter sind wir gemäß § 7 Abs.1 TMG für eigene 
Inhalte auf diesen Seiten nach den allgemeinen Gesetzen verantwortlich. Nach §§ 8 bis 10 TMG sind wir als 
Diensteanbieter jedoch nicht verpflichtet, übermittelte oder gespeicherte fremde Informationen zu überwachen oder nach 
Umständen zu forschen, die auf eine rechtswidrige Tätigkeit hinweisen. Verpflichtungen zur Entfernung oder Sperrung der 
Nutzung von Informationen nach den allgemeinen Gesetzen bleiben hiervon unberührt. Eine diesbezügliche Haftung ist 
jedoch erst ab dem Zeitpunkt der Kenntnis einer konkreten Rechtsverletzung möglich. Bei Bekanntwerden von 
entsprechenden Rechtsverletzungen werden wir diese Inhalte umgehend entfernen.

#### 2. Verweise und Links

Bei direkten oder indirekten Verweisen auf fremde Webseiten (“Hyperlinks”), die außerhalb des 
Verantwortungsbereiches der Autoren liegen, würde eine Haftungsverpflichtung ausschließlich in dem Fall in Kraft 
treten, in dem die Autoren von den Inhalten Kenntnis haben und es ihnen technisch möglich und zumutbar wäre, die 
Nutzung im Falle rechtswidriger Inhalte zu verhindern. Die Autoren erklären hiermit ausdrücklich, dass zum 
Zeitpunkt der Linksetzung keine illegalen Inhalte auf den zu verlinkenden Seiten erkennbar waren. Auf die aktuelle 
und zukünftige Gestaltung, die Inhalte oder die Urheberschaft der gelinkten/verknüpften Seiten haben die Autoren 
keinerlei Einfluss. Deshalb distanzieren wir uns hiermit ausdrücklich von allen Inhalten aller gelinkten 
/verknüpften Seiten, die nach der Linksetzung verändert wurden. Diese Feststellung gilt für alle innerhalb des 
eigenen Internetangebotes gesetzten Links und Verweise sowie für Fremdeinträge in von den Autoren eingerichteten 
Gästebüchern, Diskussionsforen und Mailinglisten. Für illegale, fehlerhafte oder unvollständige Inhalte und 
insbesondere für Schäden, die aus der Nutzung oder Nichtnutzung solcherart dargebotener Informationen entstehen, 
haftet allein der Anbieter der Seite, auf welche verwiesen wurde, nicht derjenige, der über Links auf die jeweilige 
Veröffentlichung lediglich verweist.

#### 3. Rechtswirksamkeit dieses Haftungsausschlusses

Dieser Haftungsausschluss ist als Teil des Internetangebotes zu betrachten, von dem aus auf diese Seite verwiesen 
wurde. Sofern Teile oder einzelne Formulierungen dieses Textes der geltenden Rechtslage nicht, nicht mehr oder 
nicht vollständig entsprechen sollten, bleiben die übrigen Teile des Dokumentes in ihrem Inhalt und ihrer 
Gültigkeit davon unberührt.

### Urheberrecht

Die durch die Seitenbetreiber erstellten Inhalte und Werke auf diesen Seiten unterliegen dem deutschen Urheberrecht. 
Die Vervielfältigung, Bearbeitung, Verbreitung und jede Art der Verwertung außerhalb der Grenzen des Urheberrechtes 
bedürfen der schriftlichen Zustimmung des jeweiligen Autors bzw. Erstellers. Downloads und Kopien dieser Seite sind 
nur für den privaten, nicht kommerziellen Gebrauch gestattet. Soweit die Inhalte auf dieser Seite nicht vom Betreiber 
erstellt wurden, werden die Urheberrechte Dritter beachtet. Insbesondere werden Inhalte Dritter als solche 
gekennzeichnet. Sollten Sie trotzdem auf eine Urheberrechtsverletzung aufmerksam werden, bitten wir um einen 
entsprechenden Hinweis. Bei Bekanntwerden von Rechtsverletzungen werden wir derartige Inhalte umgehend entfernen.

### Datenschutz

Die Nutzung unserer Webseite ist in der Regel ohne Angabe personenbezogener Daten möglich. Soweit auf unseren Seiten 
personenbezogene Daten (beispielsweise Name, Anschrift oder eMail-Adressen) erhoben werden, erfolgt dies, soweit 
möglich, stets auf freiwilliger Basis. Diese Daten werden ohne Ihre ausdrückliche Zustimmung nicht an Dritte 
weitergegeben.
Wir weisen darauf hin, dass die Datenübertragung im Internet (z.B. bei der Kommunikation per E-Mail) Sicherheitslücken 
aufweisen kann. Ein lückenloser Schutz der Daten vor dem Zugriff durch Dritte ist nicht möglich.
Der Nutzung von im Rahmen der Impressumspflicht veröffentlichten Kontaktdaten durch Dritte zur Übersendung von nicht 
ausdrücklich angeforderter Werbung und Informationsmaterialien wird hiermit ausdrücklich widersprochen. Die Betreiber 
der Seiten behalten sich ausdrücklich rechtliche Schritte im Falle der unverlangten Zusendung von Werbeinformationen, 
etwa durch Spam-Mails, vor.

